@@ -25,7 +25,6 @@ from .. import exceptions as exceptions
 
 # py2 vs py3 transition
 from ..six import text_type as unicode
-from ..six.moves.urllib.error import HTTPError
 
 from .base_adapter import BaseSiteAdapter,  makeDate
 
@@ -89,25 +88,16 @@ class FaerieArchiveComAdapter(BaseSiteAdapter):
         url = self.url+'&index=1'
         logger.debug("URL: "+url)
 
-        try:
-            data = self._fetchUrl(url)
-        except HTTPError as e:
-            if e.code == 404:
-                raise exceptions.StoryDoesNotExist(self.url)
-            else:
-                raise e
+        data = self.get_request(url)
 
         if "Access denied. This story has not been validated by the adminstrators of this site." in data:
             raise exceptions.AccessDenied(self.getSiteDomain() +" says: Access denied. This story has not been validated by the adminstrators of this site.")
 
-        # Now go hunting for all the meta data and the chapter list.
 
         ## Title and author
-        # use BeautifulSoup HTML parser to make everything easier to find.
         soup = self.make_soup(data)
         # print data
 
-        # Now go hunting for all the meta data and the chapter list.
 
         pagetitle = soup.find('div',{'id':'pagetitle'})
         ## Title
@@ -194,8 +184,7 @@ class FaerieArchiveComAdapter(BaseSiteAdapter):
                 for series in asoup.findAll('a', href=re.compile(r"series.php\?seriesid=\d+")):
                     # Find Series name from series URL.
                     series_url = 'http://'+self.host+'/'+series['href']
-                    # use BeautifulSoup HTML parser to make everything easier to find.
-                    seriessoup = self.make_soup(self._fetchUrl(series_url))
+                    seriessoup = self.make_soup(self.get_request(series_url))
                     storyas = seriessoup.findAll('a', href=re.compile(r'^viewstory.php\?sid=\d+$'))
                     i=1
                     for a in storyas:
@@ -219,7 +208,7 @@ class FaerieArchiveComAdapter(BaseSiteAdapter):
 
         logger.debug('Getting chapter text from: %s' % url)
 
-        soup = self.make_soup(self._fetchUrl(url))
+        soup = self.make_soup(self.get_request(url))
 
         div = soup.find('div', {'id' : 'story'})
 
