@@ -177,7 +177,21 @@ class BaseXenForo2ForumAdapter(BaseXenForoForumAdapter):
         return self.get_post_body(self.get_first_post(topsoup))
 
     def get_post_body(self,souptag):
-        return souptag.find('article',{'class':'message-body'}).find('div',{'class':'bbWrapper'})
+        body = souptag.find('article',{'class':'message-body'}).find('div',{'class':'bbWrapper'})
+        if self.getConfig('include_dice_rolls',False):
+            # logger.debug("body:%s"%body)
+            for fieldset in body.find_next_siblings('fieldset',class_='dice_container'):
+                logger.debug("fieldset:%s"%fieldset)
+                # body.append(fieldset.extract())
+                ## If include_dice_rolls:svg, keep the <svg>
+                ## up to the user to include
+                ## add_to_keep_html_attrs:,style,xmlns,height,width,d,x,y,transform,text-anchor,cx,cy,r
+                if self.getConfig('include_dice_rolls') != 'svg':
+                    for d in fieldset.find_all('svg'):
+                        result = d.select_one('title').extract()
+                        result.name='span'
+                        d.replace_with(result)
+        return body
 
     def get_post_created_date(self,souptag):
         return self.make_date(souptag.find('div', {'class':'message-date'}))
