@@ -205,6 +205,7 @@ class BasicCache(object):
     def set_to_cache(self,cachekey,data,redirectedurl):
         with self.cache_lock:
             self.basic_cache[cachekey] = (data,ensure_text(redirectedurl))
+            # logger.debug("set_to_cache %s->%s"%(cachekey,ensure_text(redirectedurl)))
             if self.autosave and self.filename:
                 self.save_cache()
 
@@ -233,6 +234,7 @@ class BasicCacheDecorator(FetcherDecorator):
         logger.debug(make_log('BasicCache',method,url,hit=hit))
         if hit:
             data,redirecturl = self.cache.get_from_cache(cachekey)
+            # logger.debug("from_cache %s->%s"%(cachekey,redirecturl))
             return FetcherResponse(data,redirecturl=redirecturl,fromcache=True)
 
         fetchresp = chainfn(
@@ -250,9 +252,6 @@ class BasicCacheDecorator(FetcherDecorator):
         ## up.
         if not fetchresp.fromcache:
             self.cache.set_to_cache(cachekey,data,fetchresp.redirecturl)
-            if url != fetchresp.redirecturl: # cache both?
-                # logger.debug("url != fetchresp.redirecturl:\n%s\n%s"%(url,fetchresp.redirecturl))
-                self.cache.set_to_cache(cachekey,data,url)
         return fetchresp
 
 class BrowserCacheDecorator(FetcherDecorator):
@@ -431,6 +430,9 @@ class RequestsFetcher(Fetcher):
                 self.requests_session.cookies = self.cookiejar
         return self.requests_session
 
+    def use_verify(self):
+        return not self.getConfig('use_ssl_unverified_context',False)
+
     def request(self,method,url,headers=None,parameters=None):
         '''Returns a FetcherResponse regardless of mechanism'''
         if method not in ('GET','POST'):
@@ -438,11 +440,10 @@ class RequestsFetcher(Fetcher):
         try:
             logger.debug(make_log('RequestsFetcher',method,url,hit='REQ',bar='-'))
             ## resp = requests Response object
-            verify = not self.getConfig('use_ssl_unverified_context',False)
             resp = self.get_requests_session().request(method, url,
                                                        headers=headers,
                                                        data=parameters,
-                                                       verify=verify)
+                                                       verify=self.use_verify())
             logger.debug("response code:%s"%resp.status_code)
             resp.raise_for_status() # raises RequestsHTTPError if error code.
             # consider 'cached' if from file.
@@ -497,6 +498,14 @@ class CloudScraperFetcher(RequestsFetcher):
             del headers['User-Agent']
         return headers
 
+    def use_verify(self):
+        ## cloudscraper doesn't work with verify=False, throws an
+        ## error about "Cannot set verify_mode to CERT_NONE when
+        ## check_hostname is enabled."
+        if self.getConfig('use_ssl_unverified_context',False):
+            logger.warning("use_ssl_unverified_context:true ignored when use_clouadscraper:true")
+        return True
+
     def request(self,method,url,headers=None,parameters=None):
         try:
             return super(CloudScraperFetcher,self).request(method,url,headers,parameters)
